@@ -176,21 +176,24 @@ fill_indices(GtkTreePath *tp, GtkMenuItem *menu_item, gboolean is_deep)
 	gboolean ret = FALSE;
 	GtkMenuItem *attach_widget = NULL;
 	GtkContainer *parent = GTK_CONTAINER(gtk_widget_get_parent(GTK_WIDGET(menu_item)));
-	GList *ll_children = gtk_container_get_children(GTK_CONTAINER(parent)), *ll_itr;
 
-	for (Nix = 0, ll_itr = ll_children ; ll_itr && menu_item != ll_itr->data ; ll_itr = ll_itr->next)
-		if (ll_itr->data)
-			if (IS_VALID_MENU_ITEM(ll_itr->data))
-				Nix++;
+	if (parent) {
+		GList *ll_children = gtk_container_get_children(GTK_CONTAINER(parent)), *ll_itr;
 
-	if (ll_itr) {
-		attach_widget = _hmv_private_get_attach_widget(GTK_WIDGET(parent));
+		for (Nix = 0, ll_itr = ll_children ; ll_itr && menu_item != ll_itr->data ; ll_itr = ll_itr->next)
+			if (ll_itr->data)
+				if (IS_VALID_MENU_ITEM(ll_itr->data))
+					Nix++;
 
-		gtk_tree_path_prepend_index(tp, Nix);
-		ret = TRUE;
+		if (ll_itr) {
+			attach_widget = _hmv_private_get_attach_widget(GTK_WIDGET(parent));
+
+			gtk_tree_path_prepend_index(tp, Nix);
+			ret = TRUE;
+		}
+
+		g_list_free(ll_children);
 	}
-
-	g_list_free(ll_children);
 	return (attach_widget && is_deep) ? fill_indices(tp, attach_widget, is_deep) : ret;
 }
 
